@@ -19,21 +19,26 @@ import feedparser, pickle, time
 import os.path
 from os import mkdir
 import md5
+import logging
+log = logging.getLogger(__name__)
+log.setLevel(logging.DEBUG)
+
+class FeedDateTimeException(Exception):
+    pass
 
 class parse(object):
 
-    def __init__(self,feed_url,service):
+    def __init__(self,feed_url,service, alias):
         self.feed_url = feed_url
         self.service = service
         self.feed = feedparser.parse(feed_url)
-
-    def getStampFileName(self):
-        self.md5name = md5.md5(self.feed_url + self.service).hexdigest()
+        self.alias = alias
         self.directory = os.path.expanduser("~/.feed2mb/")
-        self.filename = self.directory + self.md5name
+
+        md5name = md5.md5(self.feed_url + self.service).hexdigest()
+        self.filename = self.directory + md5name
 
     def updateLastRead(self,item=None):
-        self.getStampFileName()
         if not os.path.exists(self.directory):
             mkdir(self.directory)
         output = open(self.filename, 'wb')
@@ -47,11 +52,13 @@ class parse(object):
                 key = 'published_parsed'
             else:
                 key = 'updated_parsed'
+            if item[key] is None:
+                raise FeedDateTimeException("Your item on " + self.alias+ " doesn't appear to have a valid date of publication. Feed2mb needs it!")
             pickle.dump(item[key], output)
         output.close()
 
     def getlastRead(self):
-        self.getStampFileName()
+        log.debug('Getting the last time that the feed on ' + self.alias+ ' was published')
         try:
             pick = open(self.filename, 'rb')
         except IOError:
